# iblqt

A collection of extensions to the Qt framework.

The full API documentation is available [here](https://int-brain-lab.github.io/iblqt).

![License](https://img.shields.io/github/license/int-brain-lab/iblqt)
[![GitHub tag](https://img.shields.io/github/v/tag/int-brain-lab/iblqt)](https://github.com/int-brain-lab/iblqt/tags)
[![PyPI](https://img.shields.io/pypi/v/iblqt)](https://pypi.org/project/iblqt/)
[![Coverage Status](https://coveralls.io/repos/github/int-brain-lab/iblqt/badge.svg)](https://coveralls.io/github/int-brain-lab/iblqt)